<img src="./hippoformer-fig6.png" width="400px"></img>

## Hippoformer (wip)

Implementation of [Hippoformer](https://openreview.net/forum?id=hxwV5EubAw), Integrating Hippocampus-inspired Spatial Memory with Transformers

[Temporary Discord](https://discord.gg/MkACrrkrYR)

## Citations

```bibtex
@inproceedings{anonymous2025hippoformer,
    title   = {Hippoformer: Integrating Hippocampus-inspired Spatial Memory with Transformers},
    author  = {Anonymous},
    booktitle = {Submitted to The Fourteenth International Conference on Learning Representations},
    year    = {2025},
    url     = {https://openreview.net/forum?id=hxwV5EubAw},
    note    = {under review}
}
```
